pub struct PageList {
pub total_count: u32,
pub pages: Vec<Page>,
}Expand description
This object represents a list of Telegraph articles belonging to an account. Most recently created articles first.
Fields
total_count: u32Total number of pages belonging to the target Telegraph account.
pages: Vec<Page>Requested pages of the target Telegraph account.
Implementations