pub struct CreatePage {
pub access_token: String,
pub title: Title,
pub author_name: AuthorName,
pub author_url: AuthorUrl,
pub content: Content,
pub return_content: bool,
}Expand description
Use this method to create a new Telegraph page. On success, returns a Page object.
-
access_token (String) Required. Access token of the Telegraph account.
-
title (String, 1-256 characters) Required. Page title.
-
author_name (String, 0-128 characters) Author name, displayed below the article’s title.
-
author_url (String, 0-512 characters) Profile link, opened when users click on the author’s name below the title. Can be any link, not necessarily to a Telegram profile or channel.
-
content (Array of Node, up to 64 KB) Required. Content of the page.
-
return_content (Boolean, default = false) If true, a content field will be returned in the Page object (see: Content format).
Fields
access_token: Stringtitle: Titlecontent: Contentreturn_content: boolImplementations