EditAccountInfo

Struct EditAccountInfo 

pub struct EditAccountInfo {
    pub access_token: String,
    pub short_name: ShortName,
    pub author_name: Option<AuthorName>,
    pub author_url: Option<AuthorUrl>,
}
Use this method to update information about a Telegraph account. Pass only the parameters that you want to edit. On success, returns an Account object with the default fields.

Fields

access_token: Stringshort_name: ShortNameauthor_name: Option<AuthorName>author_url: Option<AuthorUrl>

Implementations

Source

impl EditAccountInfo

pub fn new(access_token: String, short_name: String) -> Self

pub fn with_raw( access_token: String, short_name: String, author_name: Option<String>, author_url: Option<String>, ) -> Self

pub async fn run( &mut self, f: Box<dyn for<'a> Fn(&'a mut EditAccountInfo) -> Pin<Box<dyn Future<Output = Ret<Account>> + 'a>>>, ) -> Ret<Account>