pub struct GetPageList {
pub access_token: String,
pub offset: u32,
pub limit: Limit,
}Expand description
Use this method to get a list of pages belonging to a Telegraph account. Returns a PageList object, sorted by most recently created pages first.
-
access_token (String) Required. Access token of the Telegraph account.
-
offset (Integer, default = 0) Sequential number of the first page to be returned.
-
limit (Integer, 0-200, default = 50) Limits the number of pages to be retrieved.
-
Sample request https://api.telegra.ph/getPageList?access_token=b968da509bb76866c35425099bc0989a5ec3b32997d55286c657e6994bbb&limit=3
Fields
access_token: Stringoffset: u32limit: LimitImplementations