RevokeAccessToken

Struct RevokeAccessToken 

pub struct RevokeAccessToken {
    pub access_token: String,
}
Use this method to revoke access_token and generate a new one, for example, if the user would like to reset all connected sessions, or you have reasons to believe the token was compromised. On success, returns an Account object with new access_token and auth_url fields.

Fields

access_token: String

Implementations

Source

impl RevokeAccessToken

pub fn new(access_token: String) -> Self

pub async fn run( &mut self, f: Box<dyn for<'a> Fn(&'a mut RevokeAccessToken) -> Pin<Box<dyn Future<Output = Ret<Account>> + 'a>>>, ) -> Ret<Account>