pub struct EditAccountInfo {
pub access_token: String,
pub short_name: ShortName,
pub author_name: Option<AuthorName>,
pub author_url: Option<AuthorUrl>,
}Expand description
Use this method to update information about a Telegraph account. Pass only the parameters that you want to edit. On success, returns an Account object with the default fields.
-
access_token (String) Required. Access token of the Telegraph account.
-
short_name (String, 1-32 characters) New account name.
-
author_name (String, 0-128 characters) New default author name used when creating new articles.
-
author_url (String, 0-512 characters) New default profile link, opened when users click on the author’s name below the title. Can be any link, not necessarily to a Telegram profile or channel.
Fields
access_token: Stringshort_name: ShortNameImplementations
Sourceimpl EditAccountInfo
impl EditAccountInfo
pub fn new(access_token: String, short_name: String) -> Self
pub fn with_raw( access_token: String, short_name: String, author_name: Option<String>, author_url: Option<String>, ) -> Self
pub async fn run( &mut self, f: Box<dyn for<'a> Fn(&'a mut EditAccountInfo) -> Pin<Box<dyn Future<Output = Ret<Account>> + 'a>>>, ) -> Ret<Account>