pub struct RevokeAccessToken {
pub access_token: String,
}Expand description
Use this method to revoke access_token and generate a new one, for example, if the user would like to reset all connected sessions, or you have reasons to believe the token was compromised. On success, returns an Account object with new access_token and auth_url fields.
-
access_token (String) Required. Access token of the Telegraph account.
-
Sample request https://api.telegra.ph/revokeAccessToken?access_token=b968da509bb76866c35425099bc0989a5ec3b32997d55286c657e6994bbb
Fields
access_token: StringImplementations